@@ -1,7 +1,7 @@
 #: Helper functions
 
-from xoa_driver.internals.core.transporter.funcs import (
-    apply, 
+from xoa_driver.internals.core.funcs import (
+    apply,
     apply_iter,
 )
 
@@ -9,4 +9,4 @@ from xoa_driver.internals.core.transporter.funcs import (
 __all__ = (
     "apply",
     "apply_iter",
-)
\ No newline at end of file
+)
